from app.utils.env import get_env_variable, set_env_variable

KEY_VARIABLE = "OPENAI_API_KEY"

def save_key(key):
    set_env_variable(KEY_VARIABLE, key)

def load_key():
    return get_env_variable(KEY_VARIABLE)


def read_env_variables():
    try:
        file = open(".env", "r")
        keys = {}
        
        for line in file.readlines():
            split = line.split("=")

            if len(split) != 2:
                continue

            key, val = split

            keys[key] = val

        file.close()

        return keys
    except:
        return {}


def write_env_variables(keys):
    file = open(".env", "w")

    for key, val in keys.items():
        file.write("{}={}\n".format(key, val))

    file.close()


def set_env_variable(key, value):
    keys = read_env_variables()
    keys[key] = value
    write_env_variables(keys)

def get_env_variable(key):
    keys = read_env_variables()
    return keys.get(key)


import click

from app.models.chat import Chat

from app.utils.consts import ERROR_MESSAGE
from app.utils.cache import load_key, save_key
from app.utils.print import print_error
from app.utils.validation import is_valid_key

@click.command()
@click.option("-k", "--key", prompt="Enter your OpenAI API key", prompt_required=not bool(load_key()))
def main(key=None):
    if not key:
        key = load_key()
        
    elif is_valid_key(key):
        save_key(key)

    else:
        print_error(ERROR_MESSAGE["bad_format_key"])
        quit()

    click.echo()
    chat = Chat(key)

    while True:
        prompt = click.prompt("", prompt_suffix="> ")

        if prompt == "!quit":
            break

        chat.send_message(prompt)



import time
import click

USER_COLOR="white"
BOT_COLOR="blue"

def get_role_color(role):
    return USER_COLOR if role == "user" else BOT_COLOR

def print_message(message):
    click.echo(click.style("> ", fg=BOT_COLOR), nl=False)

    message["content"] = message["content"].strip()

    for character in message["content"]:
        click.echo(click.style(character, fg=BOT_COLOR), nl=False)
        time.sleep(0.02)

    click.echo()
    click.echo()

def print_error(error):
    click.echo(click.style("[ERROR] {}\n".format(error), fg="red"))